# Sample & test files - where they came from
All test and sample files have either been created specifically for these tests, or have been taken within license
from a listed source. If a file has been downloaded from an external provider for use, and has been modified,
modifications are noted.

* `src/tests/assets/sample-5s-compressed.mp4` - https://samplelib.com, hyper compressed test video. Modified source.
* `src/tests/assets/sample-15s.ogg` - https://samplelib.com, test audio. Compressed, modified source.
* `src/tests/assets/sample-clouds.avif` - https://samplelib.com, test image. Compressed, modified source.
* `src/tests/assets/sample-ipsum-10.txt` - https://samplelib.com, test text.
* `stc/tests/assets/sample-jpeg.jpg` - [Photo by Anna Shvets from Pexels (unmodified)](https://www.pexels.com/photo/workplace-of-artist-with-paper-drafts-and-paint-tubes-5641889/) 
